/*
 @copyright (C) 2020 Intel Corporation

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions
 and limitations under the License.

 SPDX-License-Identifier: Apache-2.0
*/

/**************************************************************************//**
 @file gna2-capability-api.h
 @brief Gaussian and Neural Accelerator (GNA) 2.0 API Definition.
 @nosubgrouping

 ******************************************************************************

 @addtogroup GNA2_API
 @{
 ******************************************************************************

 @addtogroup GNA2_CAPABILITY_API Capability API

 API for querying capabilities of hardware devices and library.

 @{
 *****************************************************************************/

#ifndef __GNA2_CAPABILITY_API_H
#define __GNA2_CAPABILITY_API_H

#include "gna2-common-api.h"

/**
 List of device generations.

 Generation determines the set of capabilities common amongst multiple device versions.
 @see Gna2DeviceVersion.
 */
enum Gna2DeviceGeneration
{
    /**
     Legacy device supporting only Gaussian Mixture Models scoring.
     */
    Gna2DeviceGenerationGmm = 0x010,

    /**
     Initial GNA device generation with no CNN support.
     Backward compatible with ::Gna2DeviceGenerationGmm.
     */
    Gna2DeviceGeneration0_9 = 0x090,

    /**
     First fully featured GNA device generation.
     Backward compatible with ::Gna2DeviceGeneration0_9.
     */
    Gna2DeviceGeneration1_0 = 0x100,

    /**
     Fully featured second GNA device generation.
     Backward compatible with ::Gna2DeviceGeneration1_0.
     */
    Gna2DeviceGeneration2_0 = 0x200,
};

/**
 Gets library version string.

 @param [out] versionBuffer User allocated buffer for the version string
 @param [in] versionBufferSize The size of the versionBuffer in bytes.
        Must be at least 32 bytes long.
 @return Status of fetching the version.
    @retval Gna2StatusSuccess The version was fully serialized into the versionBuffer.
    @retval Gna2StatusMemorySizeInvalid The versionBuffer is too small.
    @retval Gna2StatusNullArgumentNotAllowed The versionBuffer was NULL.
 */
GNA2_API enum Gna2Status Gna2GetLibraryVersion(char * versionBuffer, uint32_t versionBufferSize);

#endif // __GNA2_CAPABILITY_API_H

/**
 @}
 @}
 */
